[jboss-cvs] JBossCache/src/org/jboss/cache/loader ...
Manik Surtani
msurtani at jboss.com
Sat Dec 30 12:50:01 EST 2006
User: msurtani
Date: 06/12/30 12:50:01
Modified: src/org/jboss/cache/loader
RmiDelegatingCacheLoader.java
ClusteredCacheLoader.java
LocalDelegatingCacheLoader.java CacheLoader.java
RpcDelegatingCacheLoader.java
DelegatingCacheLoader.java FileCacheLoader.java
TcpDelegatingCacheLoader.java
Log:
Major changes to restructure cache and node object model
Revision Changes Path
1.15 +9 -9 JBossCache/src/org/jboss/cache/loader/RmiDelegatingCacheLoader.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: ClusteredCacheLoader.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/src/org/jboss/cache/loader/ClusteredCacheLoader.java,v
retrieving revision 1.19
retrieving revision 1.20
diff -u -b -r1.19 -r1.20
--- ClusteredCacheLoader.java 29 Nov 2006 22:10:22 -0000 1.19
+++ ClusteredCacheLoader.java 30 Dec 2006 17:50:01 -0000 1.20
@@ -11,7 +11,6 @@
import org.jboss.cache.Fqn;
import org.jboss.cache.Modification;
import org.jboss.cache.RegionManager;
-import org.jboss.cache.TreeCache;
import org.jboss.cache.config.CacheLoaderConfig.IndividualCacheLoaderConfig;
import org.jboss.cache.marshall.MethodCall;
import org.jboss.cache.marshall.MethodCallFactory;
1.13 +11 -11 JBossCache/src/org/jboss/cache/loader/LocalDelegatingCacheLoader.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: CacheLoader.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/src/org/jboss/cache/loader/CacheLoader.java,v
retrieving revision 1.11
retrieving revision 1.12
diff -u -b -r1.11 -r1.12
--- CacheLoader.java 23 Oct 2006 05:46:39 -0000 1.11
+++ CacheLoader.java 30 Dec 2006 17:50:01 -0000 1.12
@@ -6,17 +6,17 @@
*/
package org.jboss.cache.loader;
-import org.jboss.cache.config.CacheLoaderConfig.IndividualCacheLoaderConfig;
-import org.jboss.cache.RegionManager;
-import org.jboss.cache.Fqn;
import org.jboss.cache.CacheSPI;
+import org.jboss.cache.Fqn;
import org.jboss.cache.Modification;
+import org.jboss.cache.RegionManager;
+import org.jboss.cache.config.CacheLoaderConfig.IndividualCacheLoaderConfig;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
-import java.util.Set;
-import java.util.Map;
import java.util.List;
+import java.util.Map;
+import java.util.Set;
/**
* A <code>CacheLoader</code> implementation persists and load keys to and from
@@ -41,6 +41,7 @@
{
/**
* Sets the configuration. This is called before {@link #create()} and {@link #start()}.
+ *
* @param config May be an instance of the IndividualCacheLoaderConfig base
* class, in which case the cache loader should use the
* {@link IndividualCacheLoaderConfig#getProperties() getProperties()}
@@ -196,7 +197,7 @@
/**
* Fetches the entire state for this cache from secondary storage (disk, database)
* and writes it to a provided ObjectOutputStream. State written to the provided
- * ObjectOutputStream parameter is used for initialization of a new TreeCache instance.
+ * ObjectOutputStream parameter is used for initialization of a new CacheImpl instance.
* When the state gets transferred to the new cache instance its cacheloader calls
* {@link #storeEntireState(ObjectInputStream)}
* <p/>
@@ -241,7 +242,7 @@
/**
* Fetches a portion of the state for this cache from secondary storage (disk, database)
* and writes it to a provided ObjectOutputStream. State written to the provided
- * ObjectOutputStream parameter is used for activation of a portion of a new TreeCache instance.
+ * ObjectOutputStream parameter is used for activation of a portion of a new CacheImpl instance.
* When the state gets transferred to the new cache instance its cacheloader calls
* {@link #storeState(Fqn,ObjectInputStream)}.
* <p/>
@@ -313,7 +314,7 @@
* classloaders.
* <p/>
* <strong>NOTE:</strong> This method is only intended to be used
- * by the <code>TreeCache</code> instance this cache loader is
+ * by the <code>CacheImpl</code> instance this cache loader is
* associated with.
* </p>
*
1.14 +22 -24 JBossCache/src/org/jboss/cache/loader/RpcDelegatingCacheLoader.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: DelegatingCacheLoader.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/src/org/jboss/cache/loader/DelegatingCacheLoader.java,v
retrieving revision 1.12
retrieving revision 1.13
diff -u -b -r1.12 -r1.13
--- DelegatingCacheLoader.java 23 Oct 2006 05:46:39 -0000 1.12
+++ DelegatingCacheLoader.java 30 Dec 2006 17:50:01 -0000 1.13
@@ -19,13 +19,13 @@
import java.util.Set;
/**
- * CacheLoader implementation which delegates to another TreeCache. This allows to stack caches on top of each
+ * CacheLoader implementation which delegates to another CacheImpl. This allows to stack caches on top of each
* other, allowing for hierarchical cache levels. For example, first level cache delegates to a second level cache,
* which delegates to a persistent cache.
*
* @author Bela Ban
* @author Daniel Gredler
- * @version $Id: DelegatingCacheLoader.java,v 1.12 2006/10/23 05:46:39 bstansberry Exp $
+ * @version $Id: DelegatingCacheLoader.java,v 1.13 2006/12/30 17:50:01 msurtani Exp $
*/
public abstract class DelegatingCacheLoader extends AbstractCacheLoader
{
1.28 +9 -9 JBossCache/src/org/jboss/cache/loader/FileCacheLoader.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: FileCacheLoader.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/src/org/jboss/cache/loader/FileCacheLoader.java,v
retrieving revision 1.27
retrieving revision 1.28
diff -u -b -r1.27 -r1.28
--- FileCacheLoader.java 8 Dec 2006 18:49:17 -0000 1.27
+++ FileCacheLoader.java 30 Dec 2006 17:50:01 -0000 1.28
@@ -17,15 +17,15 @@
import java.util.List;
import java.util.Map;
import java.util.Set;
-import java.util.regex.Pattern;
-import java.util.regex.Matcher;
import java.util.concurrent.ConcurrentHashMap;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
/**
* Simple file-based CacheLoader implementation. Nodes are directories, attributes of a node is a file in the directory
*
* @author Bela Ban
- * @version $Id: FileCacheLoader.java,v 1.27 2006/12/08 18:49:17 genman Exp $
+ * @version $Id: FileCacheLoader.java,v 1.28 2006/12/30 17:50:01 msurtani Exp $
*/
public class FileCacheLoader extends AbstractCacheLoader
{
@@ -42,12 +42,12 @@
Map<Object, List<Modification>> transactions = new ConcurrentHashMap();
/**
- * TreeCache data file.
+ * CacheImpl data file.
*/
public static final String DATA = "data.dat";
/**
- * TreeCache directory suffix.
+ * CacheImpl directory suffix.
*/
public static final String DIR_SUFFIX = "fdb";
1.7 +11 -11 JBossCache/src/org/jboss/cache/loader/TcpDelegatingCacheLoader.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: TcpDelegatingCacheLoader.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/src/org/jboss/cache/loader/TcpDelegatingCacheLoader.java,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -b -r1.6 -r1.7
--- TcpDelegatingCacheLoader.java 26 Oct 2006 19:30:20 -0000 1.6
+++ TcpDelegatingCacheLoader.java 30 Dec 2006 17:50:01 -0000 1.7
@@ -22,7 +22,7 @@
/**
* DelegatingCacheLoader implementation which delegates to a remote (not in the same VM)
- * TreeCache using TCP/IP for communication. Example configuration for connecting to a TcpCacheServer
+ * CacheImpl using TCP/IP for communication. Example configuration for connecting to a TcpCacheServer
* running at myHost:12345:<pre>
* <attribute name="CacheLoaderClass">org.jboss.cache.loader.TcpDelegatingCacheLoader</attribute>
* <attribute name="CacheLoaderConfig">
@@ -32,7 +32,7 @@
* </pre>
*
* @author Bela Ban
- * @version $Id: TcpDelegatingCacheLoader.java,v 1.6 2006/10/26 19:30:20 bstansberry Exp $
+ * @version $Id: TcpDelegatingCacheLoader.java,v 1.7 2006/12/30 17:50:01 msurtani Exp $
*/
public class TcpDelegatingCacheLoader extends DelegatingCacheLoader
{
@@ -136,7 +136,7 @@
Object retval = in.readObject();
if (retval instanceof Exception)
{
- throw(Exception) retval;
+ throw (Exception) retval;
}
return (Set) retval;
}
@@ -169,7 +169,7 @@
Object retval = in.readObject();
if (retval instanceof Exception)
{
- throw(Exception) retval;
+ throw (Exception) retval;
}
return (Map) retval;
}
@@ -190,7 +190,7 @@
Object retval = in.readObject();
if (retval instanceof Exception)
{
- throw(Exception) retval;
+ throw (Exception) retval;
}
return (Boolean) retval;
}
@@ -213,7 +213,7 @@
Object retval = in.readObject();
if (retval instanceof Exception)
{
- throw(Exception) retval;
+ throw (Exception) retval;
}
return retval;
}
@@ -235,7 +235,7 @@
Object retval = in.readObject();
if (retval instanceof Exception)
{
- throw(Exception) retval;
+ throw (Exception) retval;
}
}
}
@@ -261,7 +261,7 @@
Object retval = in.readObject();
if (retval instanceof Exception)
{
- throw(Exception) retval;
+ throw (Exception) retval;
}
}
}
@@ -282,7 +282,7 @@
Object retval = in.readObject();
if (retval instanceof Exception)
{
- throw(Exception) retval;
+ throw (Exception) retval;
}
return retval;
}
@@ -303,7 +303,7 @@
Object retval = in.readObject();
if (retval instanceof Exception)
{
- throw(Exception) retval;
+ throw (Exception) retval;
}
}
}
@@ -323,7 +323,7 @@
Object retval = in.readObject();
if (retval instanceof Exception)
{
- throw(Exception) retval;
+ throw (Exception) retval;
}
}
}
More information about the jboss-cvs-commits
mailing list
Index: RmiDelegatingCacheLoader.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/src/org/jboss/cache/loader/RmiDelegatingCacheLoader.java,v
retrieving revision 1.14
retrieving revision 1.15
diff -u -b -r1.14 -r1.15
--- RmiDelegatingCacheLoader.java 26 Oct 2006 19:30:20 -0000 1.14
+++ RmiDelegatingCacheLoader.java 30 Dec 2006 17:50:01 -0000 1.15
@@ -6,10 +6,10 @@
*/
package org.jboss.cache.loader;
+import org.jboss.cache.CacheImpl;
import org.jboss.cache.CacheSPI;
-import org.jboss.cache.DataNode;
import org.jboss.cache.Fqn;
-import org.jboss.cache.TreeCache;
+import org.jboss.cache.Node;
import org.jboss.cache.config.CacheLoaderConfig.IndividualCacheLoaderConfig;
import org.jboss.cache.loader.rmi.RemoteTreeCache;
@@ -21,8 +21,8 @@
/**
* DelegatingCacheLoader implementation which delegates to a remote (not in the same VM)
* TreeCache using the Java RMI mechanism. If configured via an XML configuration file,
* the remote TreeCache delegated to is this cacheloader's cache's coordinator. If
* configured programmatically, this cacheloader may delegate to any remote cache that
* has been appropriately bound.
* <p/>
@@ -33,12 +33,12 @@
* cacheloader's cache's cluster name.
*
* @author Daniel Gredler
- * @version $Id: RmiDelegatingCacheLoader.java,v 1.14 2006/10/26 19:30:20 bstansberry Exp $
+ * @version $Id: RmiDelegatingCacheLoader.java,v 1.15 2006/12/30 17:50:01 msurtani Exp $
*/
public class RmiDelegatingCacheLoader extends DelegatingCacheLoader
{
private RmiDelegatingCacheLoaderConfig config = new RmiDelegatingCacheLoaderConfig();
- private TreeCache cache;
+ private CacheImpl cache;
private RemoteTreeCache remoteCache;
private boolean programmaticInit;
@@ -58,7 +58,7 @@
* @param port The port on which to look up the remote object.
* @param bindName The name to which the remote object is bound.
*/
- public RmiDelegatingCacheLoader(TreeCache cache, String host, int port, String bindName)
+ public RmiDelegatingCacheLoader(CacheImpl cache, String host, int port, String bindName)
{
this.cache = cache;
config.setHost(host);
@@ -123,7 +123,7 @@
*/
protected Map delegateGet(Fqn name) throws Exception
{
- DataNode n = this.remoteCache != null ? this.remoteCache.get(name) : null;
+ Node n = this.remoteCache != null ? this.remoteCache.get(name) : null;
if (n == null)
{
return null;
@@ -21,8 +21,8 @@
/**
* DelegatingCacheLoader implementation which delegates to a remote (not in the same VM)
- * TreeCache using the Java RMI mechanism. If configured via an XML configuration file,
- * the remote TreeCache delegated to is this cacheloader's cache's coordinator. If
+ * CacheImpl using the Java RMI mechanism. If configured via an XML configuration file,
+ * the remote CacheImpl delegated to is this cacheloader's cache's coordinator. If
* configured programmatically, this cacheloader may delegate to any remote cache that
* has been appropriately bound.
1.20 +0 -1 JBossCache/src/org/jboss/cache/loader/ClusteredCacheLoader.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: LocalDelegatingCacheLoader.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/src/org/jboss/cache/loader/LocalDelegatingCacheLoader.java,v
retrieving revision 1.12
retrieving revision 1.13
diff -u -b -r1.12 -r1.13
--- LocalDelegatingCacheLoader.java 23 Oct 2006 05:46:39 -0000 1.12
+++ LocalDelegatingCacheLoader.java 30 Dec 2006 17:50:01 -0000 1.13
@@ -6,9 +6,9 @@
*/
package org.jboss.cache.loader;
-import org.jboss.cache.DataNode;
+import org.jboss.cache.CacheImpl;
import org.jboss.cache.Fqn;
-import org.jboss.cache.TreeCache;
+import org.jboss.cache.Node;
import org.jboss.cache.config.CacheLoaderConfig.IndividualCacheLoaderConfig;
import java.io.ObjectInputStream;
@@ -18,10 +18,10 @@
import java.util.Set;
/**
* DelegatingCacheLoader implementation which delegates to a local (in the same VM) TreeCache. Sample code:
* <pre>
- * TreeCache firstLevel=new TreeCache();
- * TreeCache secondLevel=new TreeCache();
+ * CacheImpl firstLevel=new CacheImpl();
+ * CacheImpl secondLevel=new CacheImpl();
* DelegatingCacheLoader l=new DelegatingCacheLoader(secondLevel);
* l.setCache(firstLevel);
* firstLevel.setCacheLoader(l);
@@ -31,19 +31,19 @@
*
* @author Bela Ban
* @author Daniel Gredler
- * @version $Id: LocalDelegatingCacheLoader.java,v 1.12 2006/10/23 05:46:39 bstansberry Exp $
+ * @version $Id: LocalDelegatingCacheLoader.java,v 1.13 2006/12/30 17:50:01 msurtani Exp $
*/
public class LocalDelegatingCacheLoader extends DelegatingCacheLoader
{
IndividualCacheLoaderConfig config;
- TreeCache delegate = null;
+ CacheImpl delegate = null;
public LocalDelegatingCacheLoader()
{
}
- public LocalDelegatingCacheLoader(TreeCache delegate)
+ public LocalDelegatingCacheLoader(CacheImpl delegate)
{
this.delegate = delegate;
}
@@ -70,7 +70,7 @@
protected Map delegateGet(Fqn name) throws Exception
{
- DataNode n = delegate.get(name);
+ Node n = delegate.get(name);
if (n == null) return null;
// after this stage we know that the node exists. So never return a null - at worst, an empty map.
Map m = n.getData();
@@ -78,7 +78,7 @@
return m;
}
- protected void setDelegateCache(TreeCache delegate)
+ protected void setDelegateCache(CacheImpl delegate)
{
this.delegate = delegate;
}
@@ -18,10 +18,10 @@
import java.util.Set;
/**
- * DelegatingCacheLoader implementation which delegates to a local (in the same VM) TreeCache. Sample code:
+ * DelegatingCacheLoader implementation which delegates to a local (in the same VM) CacheImpl. Sample code:
* <pre>
1.12 +26 -25 JBossCache/src/org/jboss/cache/loader/CacheLoader.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: RpcDelegatingCacheLoader.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/src/org/jboss/cache/loader/RpcDelegatingCacheLoader.java,v
retrieving revision 1.13
retrieving revision 1.14
diff -u -b -r1.13 -r1.14
--- RpcDelegatingCacheLoader.java 26 Oct 2006 19:30:20 -0000 1.13
+++ RpcDelegatingCacheLoader.java 30 Dec 2006 17:50:01 -0000 1.14
@@ -6,10 +6,10 @@
*/
package org.jboss.cache.loader;
+import org.jboss.cache.CacheImpl;
import org.jboss.cache.CacheSPI;
-import org.jboss.cache.DataNode;
import org.jboss.cache.Fqn;
-import org.jboss.cache.TreeCache;
+import org.jboss.cache.NodeSPI;
import org.jboss.cache.config.CacheLoaderConfig.IndividualCacheLoaderConfig;
import org.jboss.cache.lock.TimeoutException;
import org.jboss.cache.marshall.MethodCall;
@@ -26,7 +26,7 @@
/**
* DelegatingCacheLoader implementation which delegates to a remote (not in the same VM)
* TreeCache using JGroups' RPC mechanism. The remote TreeCache delegated to is this
* cacheloader's cache's coordinator.
* <p/>
* This CacheLoader uses an optional configuration property, <tt>timeout</tt>, which
@@ -34,7 +34,7 @@
* specified, it defaults to <tt>5000</tt>.
*
* @author Daniel Gredler
- * @version $Id: RpcDelegatingCacheLoader.java,v 1.13 2006/10/26 19:30:20 bstansberry Exp $
+ * @version $Id: RpcDelegatingCacheLoader.java,v 1.14 2006/12/30 17:50:01 msurtani Exp $
*/
public class RpcDelegatingCacheLoader extends DelegatingCacheLoader
{
@@ -62,17 +62,17 @@
{
try
{
- METHOD_GET_STATE = TreeCache.class.getDeclaredMethod("getStateBytes", new Class[]{});
- METHOD_SET_STATE = TreeCache.class.getDeclaredMethod("setStateBytes", new Class[]{byte[].class});
- METHOD_GET_CHILDREN_NAMES = TreeCache.class.getDeclaredMethod("getChildrenNames", new Class[]{Fqn.class});
- METHOD_GET_WITH_2_PARAMS = TreeCache.class.getDeclaredMethod("get", new Class[]{Fqn.class, Object.class});
- METHOD_GET_WITH_1_PARAM = TreeCache.class.getDeclaredMethod("get", new Class[]{Fqn.class});
- METHOD_EXISTS = TreeCache.class.getDeclaredMethod("exists", new Class[]{Fqn.class});
- METHOD_PUT_WITH_3_PARAMS = TreeCache.class.getDeclaredMethod("put", new Class[]{Fqn.class, Object.class, Object.class});
- METHOD_PUT_WITH_2_PARAMS = TreeCache.class.getDeclaredMethod("put", new Class[]{Fqn.class, Map.class});
- METHOD_REMOVE_WITH_2_PARAMS = TreeCache.class.getDeclaredMethod("remove", new Class[]{Fqn.class, Object.class});
- METHOD_REMOVE_WITH_1_PARAM = TreeCache.class.getDeclaredMethod("remove", new Class[]{Fqn.class});
- METHOD_REMOVE_DATA = TreeCache.class.getDeclaredMethod("removeData", new Class[]{Fqn.class});
+ METHOD_GET_STATE = CacheImpl.class.getDeclaredMethod("getStateBytes", new Class[]{});
+ METHOD_SET_STATE = CacheImpl.class.getDeclaredMethod("setStateBytes", new Class[]{byte[].class});
+ METHOD_GET_CHILDREN_NAMES = CacheImpl.class.getDeclaredMethod("getChildrenNames", new Class[]{Fqn.class});
+ METHOD_GET_WITH_2_PARAMS = CacheImpl.class.getDeclaredMethod("get", new Class[]{Fqn.class, Object.class});
+ METHOD_GET_WITH_1_PARAM = CacheImpl.class.getDeclaredMethod("get", new Class[]{Fqn.class});
+ METHOD_EXISTS = CacheImpl.class.getDeclaredMethod("exists", new Class[]{Fqn.class});
+ METHOD_PUT_WITH_3_PARAMS = CacheImpl.class.getDeclaredMethod("put", new Class[]{Fqn.class, Object.class, Object.class});
+ METHOD_PUT_WITH_2_PARAMS = CacheImpl.class.getDeclaredMethod("put", new Class[]{Fqn.class, Map.class});
+ METHOD_REMOVE_WITH_2_PARAMS = CacheImpl.class.getDeclaredMethod("remove", new Class[]{Fqn.class, Object.class});
+ METHOD_REMOVE_WITH_1_PARAM = CacheImpl.class.getDeclaredMethod("remove", new Class[]{Fqn.class});
+ METHOD_REMOVE_DATA = CacheImpl.class.getDeclaredMethod("removeData", new Class[]{Fqn.class});
}
catch (NoSuchMethodException ex)
{
@@ -101,8 +101,6 @@
/**
* Allows configuration via XML config file.
- *
- * @see DelegatingCacheLoader#setConfig(java.util.Properties)
*/
public void setConfig(IndividualCacheLoaderConfig base)
{
@@ -131,7 +129,7 @@
// See http://jira.jboss.com/jira/browse/JBCACHE-118 for why this is commented out.
/**
- * @see org.jboss.cache.loader.DelegatingCacheLoader#delegateGet(org.jboss.cache.Fqn, java.lang.Object)
+ * @see org.jboss.cache.loader.DelegatingCacheLoader#delegateGet(org.jboss.cache.Fqn,java.lang.Object)
*/
// protected Object delegateGet(Fqn name, Object key) throws Exception {
// return this.doMethodCall( METHOD_GET_WITH_2_PARAMS, new Object[] { name, key } );
@@ -142,7 +140,7 @@
*/
protected Map delegateGet(Fqn name) throws Exception
{
- DataNode n = (DataNode) this.doMethodCall(METHOD_GET_WITH_1_PARAM, new Object[]{name});
+ NodeSPI n = (NodeSPI) this.doMethodCall(METHOD_GET_WITH_1_PARAM, new Object[]{name});
if (n == null)
{
return null;
@@ -160,7 +158,7 @@
}
/**
- * @see org.jboss.cache.loader.DelegatingCacheLoader#delegatePut(org.jboss.cache.Fqn, java.lang.Object, java.lang.Object)
+ * @see org.jboss.cache.loader.DelegatingCacheLoader#delegatePut(org.jboss.cache.Fqn,java.lang.Object,java.lang.Object)
*/
protected Object delegatePut(Fqn name, Object key, Object value) throws Exception
{
@@ -168,7 +166,7 @@
}
/**
- * @see org.jboss.cache.loader.DelegatingCacheLoader#delegatePut(org.jboss.cache.Fqn, java.util.Map)
+ * @see org.jboss.cache.loader.DelegatingCacheLoader#delegatePut(org.jboss.cache.Fqn,java.util.Map)
*/
protected void delegatePut(Fqn name, Map attributes) throws Exception
{
@@ -176,7 +174,7 @@
}
/**
- * @see org.jboss.cache.loader.DelegatingCacheLoader#delegateRemove(org.jboss.cache.Fqn, java.lang.Object)
+ * @see org.jboss.cache.loader.DelegatingCacheLoader#delegateRemove(org.jboss.cache.Fqn,java.lang.Object)
*/
protected Object delegateRemove(Fqn name, Object key) throws Exception
{
@@ -26,7 +26,7 @@
/**
* DelegatingCacheLoader implementation which delegates to a remote (not in the same VM)
- * TreeCache using JGroups' RPC mechanism. The remote TreeCache delegated to is this
+ * CacheImpl using JGroups' RPC mechanism. The remote CacheImpl delegated to is this
* cacheloader's cache's coordinator.
* <p/>
1.13 +2 -2 JBossCache/src/org/jboss/cache/loader/DelegatingCacheLoader.java
(In the diff below, changes in quantity of whitespace are not shown.)